@@ -258,8 +258,6 @@ def find_differences(pkg_config, config_diff, differences=[], chain=[]):
     chain -- a package chain
     '''
     output = differences
-    Logger.info("package_config: %s" % pkg_config)
-    Logger.info("config_diff: %s" % config_diff)
     for key in pkg_config.keys():
         if type(pkg_config[key]) == type({}):
             if key not in config_diff:
@@ -392,8 +390,9 @@ class Bombardier:
             pkns_left = []
             map(pkns_left.append, install_order)
             for pkn in install_order:
-                msg = "Packages remaining to install (in order): %s"
-                Logger.info(msg % pkns_left)
+                msg = "Packages remaining to install (in order):"
+                for pkn in pkns_left:
+                    Logger.info("  +   %s" % pkn)
                 pkns_left.remove(pkn)
                 pkg = add_pkd[pkn]
                 erstr = "Currently installing package priority %s [%s]"
@@ -605,10 +604,14 @@ class Bombardier:
         pkns -- a list of package names to check
         """
         updated_pkns = pkns.copy()
+        vpkgs = VirtualPackages(self.repository.pkg_data)
+
         for pkn in pkns:
-            pkg = self._get_new_pkg(pkn)
+            apkn = vpkgs.get_actual_pkn(pkn, pkns)
+            pkg = self._get_new_pkg(apkn)
             pkg.initialize()
-            updated_pkns.update(pkg.dependencies)
+            for dep in pkg.dependencies:
+                updated_pkns.update([vpkgs.get_actual_pkn(dep, pkns)])
         if updated_pkns.difference(pkns):
             updated_pkns = self._examine_dependencies(updated_pkns)
         return updated_pkns
@@ -674,8 +677,6 @@ class Bombardier:
         pkg = self._get_new_pkg(pkn)
         pkg_config = pkg.get_configuration()
         config_hash_path = os.path.join(pkg.get_path(), HASH_FILE)
-        msg = "The configuration for this package was saved here: %s"
-        Logger.info(msg % config_hash_path)
         config_diff = self.config.check_hash(config_hash_path)
         differences = find_differences(pkg_config, config_diff, [])
         return differences
@@ -692,7 +693,7 @@ class Bombardier:
         '''
         status = OK
         remove_full_pkns = []
-        Logger.info("UninstallOrder: %s" % uninstall_order)
+        #Logger.info("UninstallOrder: %s" % uninstall_order)
         for name in uninstall_order:
             if del_pkd[name].full_name:
                 name_str = del_pkd[name].full_name
@@ -815,7 +816,7 @@ class Bombardier:
             Logger.info("Reconcile starting...")
 
         add_pkd, del_pkd, uninstall_order = self._ck_inst_stat(pkns)
-        Logger.info("uninstall_order: %s" % uninstall_order)
+        #Logger.info("uninstall_order: %s" % uninstall_order)
         status = self._uninstall_pkgs(del_pkd, uninstall_order,
                                           dry_run)
         if status == FAIL:
